@@ -215,7 +215,8 @@ QStringList CommandOptions::setOptions(QCommandLineParser* parser, const QString
                                        QStringLiteral("address"));
     mOptions[NAME]
               = new QCommandLineOption(QStringList{QStringLiteral("n"), QStringLiteral("name")},
-                                       i18n("Name of alarm"));
+                                       i18n("Name of alarm"),
+                                       QStringLiteral("name"));
     mOptions[NOTIFY]
               = new QCommandLineOption(QStringList{QStringLiteral("N"), QStringLiteral("notify")},
                                        i18n("Display alarm message as a notification"));
@@ -494,8 +495,7 @@ void CommandOptions::process()
         case EDIT_NEW:
             if (mParser->isSet(*mOptions.at(DISABLE)))
                 d->setErrorIncompatible(DISABLE, d->mCommandOpt);
-            // Fall through to NEW
-            [[fallthrough]];
+            [[fallthrough]];   // fall through to NEW
         case NEW:
         {
             // Display a message or file, execute a command, or send an email
@@ -949,8 +949,7 @@ bool convInterval(const QString& timeParam, KARecurrence::Type& recurType, int&
         {
             case KARecurrence::WEEKLY:
                 interval *= 7;
-                // fall through to DAILY
-                [[fallthrough]];
+                [[fallthrough]];   // fall through to DAILY
             case KARecurrence::DAILY:
                 interval *= 24*60;
                 recurType = KARecurrence::MINUTELY;
