@@ -665,6 +665,7 @@ void MainWindow::initActions()
 */
 void MainWindow::slotInitHamburgerMenu()
 {
+    delete mHamburgerMenu->menu();
     QMenu* menu = new QMenu(this);
     KActionCollection* actions = actionCollection();
     menu->addAction(actions->action(QStringLiteral("new")));
@@ -688,15 +689,6 @@ void MainWindow::enableTemplateMenuItem(bool enable)
         mWindowList[i]->mActionTemplates->setEnabled(enable);
 }
 
-/******************************************************************************
-* Refresh the alarm list in every main window instance.
-*/
-void MainWindow::refresh()
-{
-    qCDebug(KALARM_LOG) << "MainWindow::refresh";
-    DataModel::reload();
-}
-
 /******************************************************************************
 * Called when the keep archived alarm setting changes in the user preferences.
 * Enable/disable Show archived alarms option.
