@@ -963,14 +963,11 @@ void MessageDisplayHelper::playFinished()
 {
     if (mSilenceButton)
         mSilenceButton->setEnabled(false);
-    if (mAudioPlayer)   // mAudioPlayer can actually be null here!
+    const QString errmsg = AudioPlayer::popError();
+    if (!errmsg.isEmpty()  &&  !haveErrorMessage(ErrMsg_AudioFile))
     {
-        const QString errmsg = mAudioPlayer->error();
-        if (!errmsg.isEmpty()  &&  !haveErrorMessage(ErrMsg_AudioFile))
-        {
-            KAMessageBox::error(mParent->displayParent(), errmsg);
-            clearErrorMessage(ErrMsg_AudioFile);
-        }
+        KAMessageBox::error(mParent->displayParent(), errmsg);
+        clearErrorMessage(ErrMsg_AudioFile);
     }
     delete mAudioThread.data();
     if (mAlwaysHide)
@@ -1024,10 +1021,11 @@ void AudioPlayerThread::execute()
     qCDebug(KALARM_LOG) << "AudioPlayerThread::execute:" << QThread::currentThread() << mFile;
     const QUrl url = QUrl::fromUserInput(mFile);
     mFile = url.isLocalFile() ? url.toLocalFile() : url.toString();
-    mPlayer = new AudioPlayer(AudioPlayer::Alarm, url, mVolume, mFadeVolume, mFadeSeconds, this);
-    if (mPlayer->status() == AudioPlayer::Error)
+    mPlayer = AudioPlayer::create(AudioPlayer::Alarm, url, mVolume, mFadeVolume, mFadeSeconds, this);
+    if (!mPlayer  ||  mPlayer->status() == AudioPlayer::Error)
     {
         mMutex.unlock();
+        deleteLater();
         return;
     }
     connect(mPlayer, &AudioPlayer::downloaded, this, &AudioPlayerThread::checkAudioPlay);
@@ -1083,7 +1081,12 @@ void AudioPlayerThread::checkAudioPlay()
 
     // Start playing the file, either for the first time or again
     qCDebug(KALARM_LOG) << "AudioPlayerThread::checkAudioPlay: start";
-    mPlayer->play();
+    if (!mPlayer->play())
+    {
+        mMutex.unlock();
+        stop();
+        return;
+    }
     mMutex.unlock();
 }
 
@@ -1101,7 +1104,7 @@ void AudioPlayerThread::playFinished(bool ok)
         QTimer::singleShot(0, this, &AudioPlayerThread::checkAudioPlay);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     }
     else
-        exit(1);
+        deleteLater();
 }
 
 /******************************************************************************
@@ -1126,12 +1129,6 @@ void AudioPlayerThread::stop()
         deleteLater();
 }
 
-QString AudioPlayerThread::error() const
-{
-    QMutexLocker locker(&mMutex);
-    return mPlayer->error();
-}
-
 /******************************************************************************
 * Display the alarm.
 * Reply = true if the alarm should be shown, false if not.
