@@ -934,20 +934,20 @@ void RecurrenceEdit::updateEvent(KAEvent& event, bool adjustStart)
             pos.days.fill(false);
             pos.days.setBit(mMonthlyRule->dayOfWeek() - 1);
             pos.weeknum = mMonthlyRule->week();
-            QVector<KAEvent::MonthPos> poses(1, pos);
+            QList<KAEvent::MonthPos> poses(1, pos);
             event.setRecurMonthlyByPos(frequency, poses, repeatCount, endDate);
         }
         else
         {
             // It's by day
             const int daynum = mMonthlyRule->date();
-            QVector<int> daynums(1, daynum);
+            QList<int> daynums(1, daynum);
             event.setRecurMonthlyByDate(frequency, daynums, repeatCount, endDate);
         }
     }
     else if (button == mYearlyButton)
     {
-        const QVector<int> months = mYearlyRule->months();
+        const QList<int> months = mYearlyRule->months();
         if (mYearlyRule->type() == YearlyRule::POS)
         {
             // It's by position
@@ -955,7 +955,7 @@ void RecurrenceEdit::updateEvent(KAEvent& event, bool adjustStart)
             pos.days.fill(false);
             pos.days.setBit(mYearlyRule->dayOfWeek() - 1);
             pos.weeknum = mYearlyRule->week();
-            QVector<KAEvent::MonthPos> poses(1, pos);
+            QList<KAEvent::MonthPos> poses(1, pos);
             event.setRecurAnnualByPos(frequency, poses, months, repeatCount, endDate);
         }
         else
@@ -1061,7 +1061,7 @@ Rule::Rule(const QString& freqText, const QString& freqWhatsThis, bool time, boo
     auto boxLayout = new QHBoxLayout(box);
     boxLayout->setContentsMargins(0, 0, 0, 0);
 
-    QLabel* label = new QLabel(i18nc("@label:spinbox", "Recur e&very"), box);
+    QLabel* label = new QLabel(i18nc("@label:spinbox", "Recur every"), box);
     boxLayout->addWidget(label, 0, Qt::AlignLeft);
     if (time)
     {
@@ -1149,7 +1149,7 @@ DayWeekRule::DayWeekRule(const QString& freqText, const QString& freqWhatsThis,
     grid->setRowStretch(0, 1);
     layout()->addLayout(grid);
 
-    QLabel* label = new QLabel(i18nc("@label On: Tuesday", "O&n:"), this);
+    QLabel* label = new QLabel(i18nc("@label On: Tuesday", "On:"), this);
     grid->addWidget(label, 0, 0, Qt::AlignRight | Qt::AlignTop);
     grid->setColumnMinimumWidth(1, style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
 
@@ -1298,7 +1298,7 @@ MonthYearRule::MonthYearRule(const QString& freqText, const QString& freqWhatsTh
     boxLayout->setContentsMargins(0, 0, 0, 0);
     layout()->addLayout(boxLayout);
 
-    mDayButton = new RadioButton(i18nc("@option:radio On day number in the month", "O&n day"), this);
+    mDayButton = new RadioButton(i18nc("@option:radio On day number in the month", "On day"), this);
     mDayButton->setFixedSize(mDayButton->sizeHint());
     mDayButton->setReadOnly(readOnly);
     mButtonGroup->addButton(mDayButton);
@@ -1320,7 +1320,7 @@ MonthYearRule::MonthYearRule(const QString& freqText, const QString& freqWhatsTh
     boxLayout->addWidget(mDayCombo, 0, 1, 1, 2, Qt::AlignLeft);
 
     // Month position selector
-    mPosButton = new RadioButton(i18nc("@option:radio On the 1st Tuesday", "On t&he"), this);
+    mPosButton = new RadioButton(i18nc("@option:radio On the 1st Tuesday", "On the"), this);
     mPosButton->setFixedSize(mPosButton->sizeHint());
     mPosButton->setReadOnly(readOnly);
     mButtonGroup->addButton(mPosButton);
@@ -1527,7 +1527,7 @@ YearlyRule::YearlyRule(bool readOnly, QWidget* parent)
     f29box->addWidget(w, 0, Qt::AlignLeft);
     auto boxLayout = new QHBoxLayout(w);
     boxLayout->setContentsMargins(0, 0, 0, 0);
-    mFeb29Label = new QLabel(i18nc("@label:listbox", "February 2&9th alarm in non-leap years:"));
+    mFeb29Label = new QLabel(i18nc("@label:listbox", "February 29th alarm in non-leap years:"));
     boxLayout->addWidget(mFeb29Label);
     mFeb29Combo = new ComboBox();
     mFeb29Combo->setEditable(false);
@@ -1556,9 +1556,9 @@ void YearlyRule::setDefaultValues(int dayOfMonth, int dayOfWeek, int month)
 * Fetch which months have been checked (1 - 12).
 * Reply = true if February has been checked.
 */
-QVector<int> YearlyRule::months() const
+QList<int> YearlyRule::months() const
 {
-    QVector<int> mnths;
+    QList<int> mnths;
     for (int i = 0;  i < 12;  ++i)
         if (mMonthBox[i]->isChecked()  &&  mMonthBox[i]->isEnabled())
             mnths.append(i + 1);
@@ -1681,4 +1681,7 @@ bool YearlyRule::stateChanged() const
         ||  mSavedFeb29Type != feb29Type());
 }
 
+#include "moc_recurrenceedit_p.cpp"
+#include "moc_recurrenceedit.cpp"
+
 // vim: et sw=4:
